@@ -350,7 +350,7 @@ def isoform_writer(isobaric_species, lock, sptxtfile, modLibrary, aaLib, searchE
             #if there is a spectrum for the isoform, use it. Otherwise, use dummy data
             z_parent = 2  #To-Do: Better if we'd take the most common parental charge among the family
             sequence = isoform.getSequenceWithMods('TPP') # spectrum.name.split('/')[0]
-            irt_sequence = -100
+            iRT_experimental = -100000.0
             RT_experimental = -100000.0
             searchenginefiltered = False
             peaks = []
@@ -358,6 +358,11 @@ def isoform_writer(isobaric_species, lock, sptxtfile, modLibrary, aaLib, searchE
                 z_parent = float(spectrum.name.split('/')[1])
                 if spectrum.RetTime_detected != -1 :
                     RT_experimental = spectrum.RetTime_detected / 60.0   #PeakView expect minutes, and spectraST reports seconds.
+                if spectrum.iRT_detected != -1 :
+                    iRT_experimental = spectrum.iRT_detected / 60.0   #PeakView expect minutes, and spectraST reports seconds.
+                else:
+                    iRT_experimental = RT_experimental
+                if not useMinutes : iRT_experimental = iRT_experimental * 60
                 if not useMinutes : RT_experimental = RT_experimental * 60
                 try :
                     for searchengine in searchEngineconfig :
@@ -401,11 +406,11 @@ def isoform_writer(isobaric_species, lock, sptxtfile, modLibrary, aaLib, searchE
                 transition = []
                 transition_cnt += 1
                 if key == 'peakview' :
-                    transition = [ precursorMZ , fragment_mz , RT_experimental , protein_desc , 'light' ,
+                    transition = [ precursorMZ , fragment_mz , iRT_experimental , protein_desc , 'light' ,
                                     rel_intensity , isoform.sequence , isoform.getSequenceWithMods(code) , int(z_parent) ,
-                                    frg_serie , frg_z , frg_nr , irt_sequence , protein_code1 , 'FALSE']
+                                    frg_serie , frg_z , frg_nr , iRT_experimental , protein_code1 , 'FALSE']
                 if key == 'openswath' :
-                    transition = [precursorMZ, fragment_mz, RT_experimental, "%s_%s_%s" % (transition_cnt, isoform.getSequenceWithMods(code), int(z_parent)), '-1',
+                    transition = [precursorMZ, fragment_mz, iRT_experimental, "%s_%s_%s" % (transition_cnt, isoform.getSequenceWithMods(code), int(z_parent)), '-1',
                             rel_intensity, "%s_%s_%s" % (precursor_cnt, isoform.getSequenceWithMods(code), int(z_parent)), 0, isoform.sequence, protein_desc, 
                             "%s_%s_%s" %(frg_serie, frg_z, frg_nr), isoform.getSequenceWithMods(code), int(z_parent), 'light', protein_code1, frg_serie, frg_z, frg_nr ]
                 filteredtransitions.append(transition)
@@ -528,7 +533,7 @@ def transitions_isobaric_peptides(isobaric_species , sptxtfile, switchingModific
             #if there is a spectrum for the isoform, use it. Otherwise, use dummy data
             z_parent = 2  #To-Do: Better if we'd take the most common parental charge among the family
             sequence = isoform.getSequenceWithMods('TPP') # spectrum.name.split('/')[0]
-            irt_sequence = -100
+            iRT_experimental = -100000.0
             RT_experimental = -100000.0
             searchenginefiltered = False
             peaks = []
@@ -536,6 +541,11 @@ def transitions_isobaric_peptides(isobaric_species , sptxtfile, switchingModific
                 z_parent = float(spectrum.name.split('/')[1])
                 if spectrum.RetTime_detected != -1 :
                     RT_experimental = spectrum.RetTime_detected / 60.0   #PeakView expect minutes, and spectraST reports seconds.
+                if spectrum.iRT_detected != -1 :
+                    iRT_experimental = spectrum.iRT_detected / 60.0   #PeakView expect minutes, and spectraST reports seconds.
+                else:
+                    iRT_experimental = RT_experimental
+                if not useMinutes : iRT_experimental = iRT_experimental * 60
                 if not useMinutes : RT_experimental = RT_experimental * 60
                 try :
                     for searchengine in searchEngineconfig :
@@ -581,11 +591,11 @@ def transitions_isobaric_peptides(isobaric_species , sptxtfile, switchingModific
                     if key == 'peakview' :
                         if abs(uis_lossgain) > 0.05 : 
                             uis_serie = uis_serie + str(int(round(uis_lossgain)))
-                        transition = [ precursorMZ , uis_mass , RT_experimental , protein_desc , 'light' ,
+                        transition = [ precursorMZ , uis_mass , iRT_experimental , protein_desc , 'light' ,
                                         rel_intensity , isoform.sequence , isoform.getSequenceWithMods(code) , int(z_parent) ,
-                                        uis_serie , uis_frg_z , uis_nr , irt_sequence , protein_code1 , 'FALSE', uis_order, uis_masses]
+                                        uis_serie , uis_frg_z , uis_nr , iRT_experimental , protein_code1 , 'FALSE', uis_order, uis_masses]
                     if key == 'openswath' :
-                        transition = [precursorMZ, uis_mass, RT_experimental, "%s_%s_%s" % (transition_cnt, isoform.getSequenceWithMods(code), int(z_parent)), '-1',
+                        transition = [precursorMZ, uis_mass, iRT_experimental, "%s_%s_%s" % (transition_cnt, isoform.getSequenceWithMods(code), int(z_parent)), '-1',
                                 rel_intensity, "%s_%s_%s" % (precursor_cnt, isoform.getSequenceWithMods(code), int(z_parent)), 0, isoform.sequence, protein_desc, 
                                 "%s_%s_%s" %(uis_serie, uis_frg_z, uis_nr), isoform.getSequenceWithMods(code), int(z_parent), 'light', protein_code1, uis_serie, uis_frg_z, uis_nr, uis_order, uis_masses ]
                     filteredtransitions.append(transition)
@@ -628,7 +638,7 @@ def main(argv) :
     
     csv_headers_peakview =     [    'Q1', 'Q3', 'RT_detected', 'protein_name', 'isotype',
                      'relative_intensity', 'stripped_sequence', 'modification_sequence', 'prec_z',
-                     'frg_type', 'frg_z', 'frg_nr', 'iRT', 'uniprot_id', 'decoy'
+                     'frg_type', 'frg_z', 'frg_nr', 'iRT', 'uniprot_id', 'decoy' , 'N', 'confidence', 'shared'
                      ]
     csv_headers_openswath = ['PrecursorMz', 'ProductMz', 'Tr_recalibrated', 'transition_name', 'CE',
                             'LibraryIntensity', 'transition_group_id', 'decoy', 'PeptideSequence', 'ProteinName', 
@@ -638,13 +648,14 @@ def main(argv) :
     
     csv_headers = csv_headers_peakview
 
-    swaths =[(400,425),(424,450),(449,475),(474,500),(499,525),
-             (524,550),(549,575),(574,600),(599,625),(624,650),
-             (649,675),(674,700),(699,725),(724,750),(749,775),
-             (774,800),(799,825),(824,850),(849,875),(874,900),
-             (899,925),(924,950),(949,975),(974,1000),(999,1025),
-             (1024,1050),(1049,1075),(1074,1100),(1099,1125),(1124,1150),
-             (1149,1175),(1174,1200)]
+    swaths = []
+    #swaths =[(400,425),(424,450),(449,475),(474,500),(499,525),
+    #         (524,550),(549,575),(574,600),(599,625),(624,650),
+    #         (649,675),(674,700),(699,725),(724,750),(749,775),
+    #         (774,800),(799,825),(824,850),(849,875),(874,900),
+    #         (899,925),(924,950),(949,975),(974,1000),(999,1025),
+    #         (1024,1050),(1049,1075),(1074,1100),(1099,1125),(1124,1150),
+    #         (1149,1175),(1174,1200)]
 
     #Get options
     try:
@@ -784,12 +795,15 @@ def main(argv) :
         print "Reading fasta file :" , fastafile
         proteins.readFasta(fastafile)
 
+    protein_cnt = 1
+    protein_index = {}
 
     #Read swaths file (if provided)
     if swathsfile != '' :
         swaths = read_swathsfile(swathsfile)
     else:
-        print "Using default swath windows",swaths
+        #print "Using default swath windows",swaths
+        print "No swath windows set."
 
     for sptxtfile in sptxtfiles :
         print "Reading : " , sptxtfile
@@ -855,11 +869,16 @@ def main(argv) :
             #Declare the peptide
             pep = modificationsLib.translateModificationsFromSequence(sequence, modification_code, aaLib = aaLib)
             
-            irt_sequence = -100
+            iRT_experimental = 0.0
             RT_experimental = 0.0
             if spectrum.RetTime_detected != -1 :
                 RT_experimental = spectrum.RetTime_detected / 60.0   #PeakView expect minutes, and spectraST reports seconds.
+            if spectrum.iRT_detected != -1 :
+                iRT_experimental = spectrum.iRT_detected / 60.0   #PeakView expect minutes, and spectraST reports seconds.
+            else:
+                iRT_experimental = RT_experimental
 
+            if not useMinutes : iRT_experimental = iRT_experimental * 60
             if not useMinutes : RT_experimental = RT_experimental * 60
 
 
@@ -954,45 +973,27 @@ def main(argv) :
                 if key == 'openswath'     : code = 'unimod'
                 if key == 'peakview'    : code = 'ProteinPilot'
 
+                if protein_desc not in protein_index:
+                	protein_index[protein_desc] = protein_cnt
+                	protein_cnt+=1
+
+                if protein_desc[:2] == "1/":
+                	protein_shared = "FALSE"
+                else:
+                	protein_shared = "TRUE"
+
                 transition = []
                 transition_cnt += 1
                 if key == 'peakview' :
-                    transition = [
-                                  precursorMZ , # 0
-                                  fragment_mz ,
-                                  RT_experimental ,
-                                  protein_desc ,
-                                  'light' ,
-                                  peak.intensity ,
-                                  spectrum.sequence ,
-                                  pep.getSequenceWithMods(code) ,
-                                  int(z_parent) ,
-                                  peak.frg_serie ,
-                                  peak.frg_z , # 10
-                                  peak.frg_nr ,
-                                  irt_sequence ,
-                                  protein_code1 ,
-                                  'FALSE'] # 14
+                    transition = [ precursorMZ , fragment_mz , iRT_experimental , protein_desc , 'light' ,
+                                    peak.intensity , spectrum.sequence , pep.getSequenceWithMods(code) , int(z_parent) ,
+                                    peak.frg_serie , peak.frg_z , peak.frg_nr , iRT_experimental , protein_code1 , 'FALSE', protein_index[protein_desc] , 1 , protein_shared ]
                 if key == 'openswath' :
-                    transition = [
-                      precursorMZ, # 0
-                      fragment_mz,
-                      RT_experimental,
-                      "%s_%s_%s" % (transition_cnt, pep.getSequenceWithMods(code), int(z_parent)),
-                      '-1',
-                      peak.intensity,
-                      "%s_%s_%s" % (precursor_cnt, pep.getSequenceWithMods(code), int(z_parent)), 
-                      0, 
-                      spectrum.sequence,
-                      protein_desc, 
-                      peak.peak_annotation, # 10
-                      pep.getSequenceWithMods(code),
-                      int(z_parent), # 12
-                      'light', 
-                      protein_code1,
-                      peak.frg_serie, # 15
-                      peak.frg_z, # 16
-                      peak.frg_nr ] # 17
+                    transition = [precursorMZ, fragment_mz, iRT_experimental, "%s_%s_%s" % (transition_cnt, pep.getSequenceWithMods(code), int(z_parent)), '-1',
+                            peak.intensity, "%s_%s_%s" % (precursor_cnt, pep.getSequenceWithMods(code), int(z_parent)), 0, spectrum.sequence, protein_desc, 
+                            peak.peak_annotation, pep.getSequenceWithMods(code),
+                            int(z_parent), 'light', protein_code1, peak.frg_serie, peak.frg_z,
+                            peak.frg_nr ]
                 
                 filteredtransitions.append(transition)
             
@@ -1045,10 +1046,10 @@ def main(argv) :
                         precursorMZ_heavy      = heavy_transition[0]
                         fragment_mz_heavy      = heavy_transition[1]
                         sequence_heavy         = heavy_transition[8]
-                        z_parent               = heavy_transition[12]
-                        frg_serie              = heavy_transition[15]
-                        frg_z                   = heavy_transition[16]
-                        frg_number               = heavy_transition[17]
+                        z_parent               = heavy_transition[15]
+                        frg_serie              = heavy_transition[18]
+                        frg_z                   = heavy_transition[19]
+                        frg_number               = heavy_transition[20]
                                         
                     #NOTE: This only works for y- and b- ions (AND their neutral losses). Other fragment series are ignored, and no heavy transition will be generated for them.
                     if frg_serie[0] not in ['y','b'] : continue
