@@ -716,6 +716,7 @@ class Spectra:
         self.OrigMaxIntensity = -1
         self.ConsFracAssignedPeaks = -1
         self.RetTime_detected = -1
+        self.iRT_detected = -1
         self.spectra_cols = {
             'id'                :   0,
             'status'            :   1,
@@ -911,6 +912,13 @@ class Spectra:
                 mm_split_float = [float(f) for f in mm_split]
                 self.RetTime_detected = mm_split_float[0]
             else : self.RetTime_detected = float( mm.group(1) )
+        mm = re.search( 'iRT=(.*?)$', self.comment )
+        if mm:
+            if ',' in mm.group(1)[:] :
+                mm_split = mm.group(1).split(',')
+                mm_split_float = [float(f) for f in mm_split]
+                self.iRT_detected = mm_split_float[0]
+            else : self.iRT_detected = float( mm.group(1) )
 
         try :
             self.comment_parsed = self.parse_comments(self.comment)
